@@ -7,9 +7,10 @@ use Alien::Build::Plugin;
 use File::chdir;
 use File::Temp ();
 use Capture::Tiny qw( capture_merged capture );
+use Alien::Util qw( version_cmp );
 
 # ABSTRACT: Probe for system libraries by guessing with ExtUtils::CBuilder
-our $VERSION = '2.47'; # VERSION
+our $VERSION = '2.78'; # VERSION
 
 
 has options => sub { {} };
@@ -27,6 +28,9 @@ has program => 'int main(int argc, char *argv[]) { return 0; }';
 has version => undef;
 
 
+has 'atleast_version' => undef;
+
+
 has aliens => [];
 
 
@@ -130,6 +134,13 @@ sub init
       if(defined $self->version)
       {
         my($version) = $out =~ $self->version;
+        if (defined $self->atleast_version)
+        {
+          if(version_cmp ($version, $self->atleast_version) < 0)
+          {
+            die "CBuilder probe found version $version, but at least @{[ $self->atleast_version ]} is required.";
+          }
+        }
         $build->hook_prop->{version} = $version;
         $build->install_prop->{plugin_probe_cbuilder_gather}->{$self->instance_id}->{version} = $version;
       }
@@ -167,7 +178,7 @@ Alien::Build::Plugin::Probe::CBuilder - Probe for system libraries by guessing w
 
 =head1 VERSION
 
-version 2.47
+version 2.78
 
 =head1 SYNOPSIS
 
@@ -215,6 +226,10 @@ The program to use in the test.
 This is a regular expression to parse the version out of the output from the
 test program.
 
+=head2 atleast_version
+
+The minimum required version as provided by the system.
+
 =head2 aliens
 
 List of aliens to query fro compiler and linker flags.
@@ -289,9 +304,11 @@ Håkon Hægland (hakonhagland, HAKONH)
 
 nick nauwelaerts (INPHOBIA)
 
+Florian Weimer
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2011-2022 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
